/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2009 EADS DEFENCE AND SECURITY SYSTEMS
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 */

package org.ow2.weblab.services.content.provider.impl;

import java.io.File;

import javax.jws.WebService;

import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.content.binary.BinaryFolderContentManager;
import org.ow2.weblab.content.text.TextFolderContentManager;
import org.weblab_project.core.exception.WebLabCheckedException;
import org.weblab_project.services.contentprovider.ContentProvider;
import org.weblab_project.services.contentprovider.GetContentException;
import org.weblab_project.services.contentprovider.types.GetContentArgs;
import org.weblab_project.services.contentprovider.types.GetContentReturn;
import org.weblab_project.services.exception.WebLabException;


@WebService(endpointInterface = "org.weblab_project.services.contentprovider.ContentProvider")
public class ContentProviderService implements ContentProvider {

	protected BinaryFolderContentManager binaryFolderContentManager = null;

	protected TextFolderContentManager textFolderContentManager = null;

	public GetContentReturn getContent(final GetContentArgs args)
			throws GetContentException {

		this.checkArgs(args);

		if (this.binaryFolderContentManager == null) {
			this.binaryFolderContentManager = BinaryFolderContentManager
					.getInstance();
		}

		File file = this.binaryFolderContentManager.getFileFromWLRi(args
				.getContentId());
		LogFactory.getLog(this.getClass()).debug(
				"File loaded from WLRI : " + file.getAbsolutePath());
		GetContentReturn ret = new GetContentReturn();
		if (file.exists()) {
			try {
				ret.setContent(this.binaryFolderContentManager.getContent(args
						.getContentId(), args.getOffset(), args.getLimit()));
			} catch (final WebLabCheckedException wlce) {
				WebLabException wExp = new WebLabException();
				wExp.setErrorId("E1");
				wExp.setErrorMessage("Invalid parameter.");
				GetContentException exp = new GetContentException(
						"Unable to get binary content.", wExp, wlce);
				throw exp;
			}
		} else {
			if (this.textFolderContentManager == null) {
				this.textFolderContentManager = TextFolderContentManager
						.getInstance();
			}
			try {
				ret.setContent(this.textFolderContentManager.getContent(args
						.getContentId(), args.getOffset(), args.getLimit()));
			} catch (final WebLabCheckedException wlce) {
				WebLabException wExp = new WebLabException();
				wExp.setErrorId("E1");
				wExp.setErrorMessage("Invalid parameter.");
				GetContentException exp = new GetContentException(
						"Unable to get text content.", wExp, wlce);
				throw exp;
			}
		}
		return ret;
	}

	/**
	 * @param args
	 *            The <code>GetContentArgs</code>
	 */
	private void checkArgs(final GetContentArgs args)
			throws GetContentException {
		if (args == null) {
			WebLabException wExp = new WebLabException();
			wExp.setErrorId("E1");
			wExp.setErrorMessage("Invalid parameter.");
			GetContentException exp = new GetContentException(
					"GetContentArgs was null.", wExp);
			throw exp;
		} else if (args.getContentId() == null) {
			WebLabException wExp = new WebLabException();
			wExp.setErrorId("E1");
			wExp.setErrorMessage("Invalid parameter.");
			GetContentException exp = new GetContentException(
					"Content Id was null.", wExp);
			throw exp;
		}
	}

}
